@@ -1,4 +1,5 @@
 import os.path
+from os_tools import tools
 
 from os_file_stream_handler import file_stream_handler as fsh
 from os_file_handler import file_handler as fh
@@ -21,8 +22,19 @@ def prepare_ipa_file(ipa_file_path,
         app_name: the app's name
     """
 
-    # gather resources
     ipa_file_name = fh.get_file_name_from_path(ipa_file_path, with_extension=False)
+    if len(ipa_file_name.split(" ")) > 1:
+        raise Exception("Oops. It seems like your .ipa file contains spaces. Remove them and run me again!")
+    if not str(server_output_dir_path).startswith("https"):
+        tools.ask_for_input("Oops. It seems like you haven\'t set the prefix: 'https' in your server_output_dir_path."
+                            "\nApple requests that the binary should be hosted on a secure server. Continue and add 'https' to the server url?")
+        if server_output_dir_path.startswith("http"):
+            server_output_dir_path = server_output_dir_path.removeprefix("http")
+            server_output_dir_path = f'https{server_output_dir_path}'
+        else:
+            server_output_dir_path = f'https://{server_output_dir_path}'
+
+    # gather resources
     parent_path = fh.get_parent_path(ipa_file_path)
     output_path = os.path.join(parent_path, ipa_file_name)
 
